#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 trifecta
version:              2.1.4
visibility:           public
id:                   trifecta-2.1.4-4R5KlNxHEHo78hwrAV4c9u
key:                  trifecta-2.1.4-4R5KlNxHEHo78hwrAV4c9u
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/trifecta/
synopsis:
    A modern parser combinator library with convenient diagnostics

description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics

    For example:

    <<https://i.imgur.com/ZyzUSSn.png>>

    <images/example.png (Local Copy)>

category:             Text, Parsing, Diagnostics, Pretty Printer, Logging
abi:                  e40d0bec04c86e8fda711dabc084457f
exposed:              True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Tutorial Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It

hidden-modules:
    Text.Trifecta.Util.Combinators Text.Trifecta.Util.Pretty

import-dirs:          /usr/lib/ghc-9.6.6/site-local/trifecta-2.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/trifecta-2.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/trifecta-2.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-trifecta
hs-libraries:         HStrifecta-2.1.4-4R5KlNxHEHo78hwrAV4c9u
depends:
    ansi-terminal-1.1-CI3Z2kdMs2nHILfQB59SyQ array-0.5.6.0
    base-4.18.2.1 blaze-builder-0.4.4.1-4QmQvMAPyoDG7cxlUmp9Pw
    blaze-html-0.9.2.0-BrSAzNVQiYJEXfJmmg87r5
    blaze-markup-0.8.3.0-KxnUlxuVxNzAanXVU8ic4k bytestring-0.11.5.3
    charset-0.3.12-OU8UpWmOUj4ushP1JN5ll
    comonad-5.0.9-CVDDRFovdCyBCnhNUM1xFy containers-0.6.7
    deepseq-1.4.8.1 fingertree-0.1.6.2-8fHbdqLUqga7o5HTrVKraR
    ghc-prim-0.10.0 hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    lens-5.3.4-AArhojR1bHQDPd0CW0dSET mtl-2.3.1
    parsers-0.12.12-8SQd30A0FjtFXEkvloMdas
    prettyprinter-1.7.1-890hJtP71KxJCLiD1l5JnX
    prettyprinter-ansi-terminal-1.1.3-G3Jgi8iGiEwJ3EPlBOH51X
    profunctors-5.6.3-9BLFPFHf8vY849ipqks6S6
    reducers-3.12.5-Cr2gt8vVzkzGX2spLEDVN5 transformers-0.6.1.0
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:   /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html:         /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

